TODO
- Make sure Sphinx generates docs from all files
- generate html instead of md ???
- add general introduction and usage guide on the docs

Build
`hatch build` or `python -m hatch build`
`hatch publish` or `python -m hatch publish` with username `__token__`. Make sure the keyrings backend is installed.
